const int Point1ParamID = 0;    // 対角点 1 のパラメータID
const int Point2ParamID = 1;    // 対角点 2 のパラメータID

// 実行したコマンドを取得する
var currentCommand = Application.CommandManager.CurrentCommand;

// コマンドのユニーク名を比較する
if(currentCommand.UniqueName == "RootPro.Shape.Rectangle")
{
    // 対角点 1、対角点 2 の一時的なパラメータアイテムを取得
    var paramItem1 = currentCommand.GetTemporaryParameterItemByID(Point1ParamID);
    var paramItem2 = currentCommand.GetTemporaryParameterItemByID(Point2ParamID);

    // 有効な値が設定されているかチェックする
    if(paramItem1 != null && paramItem1 is PointParameterItem &&
       paramItem2 != null && paramItem2 is PointParameterItem)
    {
        var pointItem1 = (PointParameterItem)paramItem1;
        var pointItem2 = (PointParameterItem)paramItem2;

        // 領域のある四角形の場合
        if(pointItem1.Point.X != pointItem2.Point.X &&
           pointItem1.Point.Y != pointItem2.Point.Y)
        {
            // 二つの対角点から四角形の点列を作成する
            Point2d[] points = new Point2d[5];
            points[0].X = pointItem1.Point.X;
            points[0].Y = pointItem1.Point.Y;
            points[1].X = pointItem2.Point.X;
            points[1].Y = pointItem1.Point.Y;
            points[2].X = pointItem2.Point.X;
            points[2].Y = pointItem2.Point.Y;
            points[3].X = pointItem1.Point.X;
            points[3].Y = pointItem2.Point.Y;
            points[4] = points[0];

            // 点列から四角形を作成
            var polyline = Application.ShapeFactory.CreatePolyline(points);
            if(polyline != null)
            {
                // 四角形の面積を取得
                var area = polyline.GetPolygonArea();
                if(area != null)
                {
                    // 小数点第 8 位までを四捨五入
                    var roundArea = Math.Round((double)area, 8, MidpointRounding.AwayFromZero);

                    // ステータスバーに面積を 3 秒間表示する
                    Application.StatusBar.SetInformation(roundArea.ToString(), 3000);
                }
            }
        }
    }
}
